"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const uuid_1 = require("uuid");
const requests_1 = tslib_1.__importDefault(require("../requests"));
const utils_1 = require("..//utils");
const types_1 = require("../types");
const genericSteps_1 = require("./genericSteps");
const makeCommonSteps = (_constConfig, globalConfig, participant) => {
    return [
        {
            name: 'add participant',
            ignoreFailure: true,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postParticipants(globalConfig.urls.centralLedgerAdmin, {
                body: {
                    name: participant.id,
                    currency: globalConfig.currency
                }
            }))
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_PARTIES_GET`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_PARTIES_GET',
                    value: `${participant.fspiopCallbackUrl}/parties/{{partyIdType}}/{{partyIdentifier}}`
                }
            }))
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_PARTIES_PUT`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_PARTIES_PUT',
                    value: `${participant.fspiopCallbackUrl}/parties/{{partyIdType}}/{{partyIdentifier}}`
                }
            }))
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_PARTIES_PUT_ERROR`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_PARTIES_PUT_ERROR',
                    value: `${participant.fspiopCallbackUrl}/parties/{{partyIdType}}/{{partyIdentifier}}/error`
                }
            }))
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_TRX_REQ_SERVICE`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_TRX_REQ_SERVICE',
                    // TODO: this looks wrong to me!
                    value: `${participant.fspiopCallbackUrl}`
                }
            }))
        },
    ];
};
const makeDfspSteps = (_constConfig, globalConfig, participant) => {
    return [
        {
            name: 'add initial position and limits',
            ignoreFailure: true,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postParticipantsPositionAndLimits(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    currency: globalConfig.currency,
                    limit: {
                        type: "NET_DEBIT_CAP",
                        value: 1000000
                    },
                    initialPosition: 0
                }
            }))
        },
        {
            name: 'create settlement account',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(async () => {
                const participantResponse = await requests_1.default.getParticipant(globalConfig.urls.centralLedgerAdmin, participant.id);
                const settlementAccount = participantResponse.data.accounts
                    .filter(account => account.ledgerAccountType === 'SETTLEMENT')
                    .pop();
                if (!settlementAccount) {
                    throw new Error(`Settlement account not found for: ${participant.id}`);
                }
                requests_1.default.postAccount(globalConfig.urls.centralLedgerAdmin, {
                    participantId: participant.id,
                    accountId: `${settlementAccount.id}`,
                    body: {
                        transferId: uuid_1.v4(),
                        externalReference: "none",
                        action: "recordFundsIn",
                        reason: "Initial settlement amount",
                        amount: {
                            amount: "1000000",
                            currency: globalConfig.currency
                        }
                    }
                });
            })
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_PARTICIPANT_PUT`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_PARTICIPANT_PUT',
                    value: `${participant.fspiopCallbackUrl}/participants/{{partyIdType}}/{{partyIdentifier}}`
                }
            }))
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_PARTICIPANT_PUT_ERROR`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_PARTICIPANT_PUT_ERROR',
                    value: `${participant.fspiopCallbackUrl}/participants/{{partyIdType}}/{{partyIdentifier}}/error`
                }
            }))
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_PARTICIPANT_BATCH_PUT_ERROR`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_PARTICIPANT_BATCH_PUT_ERROR',
                    value: `${participant.fspiopCallbackUrl}/participants/{{requestId}}/error`
                }
            }))
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_QUOTES`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_QUOTES',
                    // TODO: this looks wrong to me...
                    value: `${participant.fspiopCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_TRANSFER_POST`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_TRANSFER_POST',
                    value: `${participant.fspiopCallbackUrl}/transfers`
                }
            }))
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_TRANSFER_PUT`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_TRANSFER_PUT',
                    value: `${participant.fspiopCallbackUrl}/transfers/{{transferId}}`
                }
            }))
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_TRANSFER_ERROR`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_TRANSFER_ERROR',
                    value: `${participant.fspiopCallbackUrl}/transfers/{{transferId}}/error`
                }
            }))
        },
        {
            name: 'register email `NET_DEBIT_CAP_ADJUSTMENT_EMAIL`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'NET_DEBIT_CAP_ADJUSTMENT_EMAIL',
                    value: `email@example.com`
                }
            }))
        },
        {
            name: 'register email `SETTLEMENT_TRANSFER_POSITION_CHANGE_EMAIL`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'SETTLEMENT_TRANSFER_POSITION_CHANGE_EMAIL',
                    value: `email@example.com`
                }
            }))
        },
        {
            name: 'register email `NET_DEBIT_CAP_THRESHOLD_BREACH_EMAIL`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'NET_DEBIT_CAP_THRESHOLD_BREACH_EMAIL',
                    value: `email@example.com`
                }
            }))
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_BULK_TRANSFER_POST`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_BULK_TRANSFER_POST',
                    value: `${participant.fspiopCallbackUrl}/bulkTransfers`
                }
            }))
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_BULK_TRANSFER_PUT`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_BULK_TRANSFER_PUT',
                    value: `${participant.fspiopCallbackUrl}/bulkTransfers/{{id}}`
                }
            }))
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_BULK_TRANSFER_ERROR`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_BULK_TRANSFER_ERROR',
                    value: `${participant.fspiopCallbackUrl}/bulkTransfers/{{id}}/error`
                }
            }))
        },
    ];
};
const makeDFSPSupportingPISPSteps = (_constConfig, globalConfig, participant) => {
    return [
        {
            name: 'register endpoint `TP_CB_URL_ACCOUNTS_GET`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_ACCOUNTS_GET',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_AUTHORIZATIONS`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_AUTHORIZATIONS',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_TRANSACTION_REQUEST_POST`',
            // TODO: fix this - we shouldn't have to ignore failure here
            ignoreFailure: true,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_TRANSACTION_REQUEST_POST',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_TRANSACTION_REQUEST_AUTH_POST`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_TRANSACTION_REQUEST_AUTH_POST',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_CONSENT_REQUEST_POST`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_CONSENT_REQUEST_POST',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_CONSENT_REQUEST_PATCH`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_CONSENT_REQUEST_PATCH',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_UsRL_CONSENT_PUT`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_CONSENT_PUT',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        // TODO: this is an auth service endpoint, it should be in it's own makeAuthService steps section
        {
            name: 'register endpoint `TP_CB_URL_CONSENT_POST`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_CONSENT_POST',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_CONSENT_PUT_ERROR`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_CONSENT_PUT_ERROR',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_TRANSACTION_REQUEST_POST`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_TRANSACTION_REQUEST_POST',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_TRANSACTION_REQUEST_PUT_ERROR`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_TRANSACTION_REQUEST_PUT_ERROR',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
    ];
};
const makePispSteps = (_constConfig, globalConfig, participant) => {
    return [
        {
            name: 'register endpoint `TP_CB_URL_TRANSACTION_REQUEST_PATCH`',
            // TODO: fix this - we shouldn't have to ignore failure here
            ignoreFailure: true,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_TRANSACTION_REQUEST_PATCH',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_TRANSACTION_REQUEST_POST`',
            // TODO: fix this - we shouldn't have to ignore failure here
            ignoreFailure: true,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_TRANSACTION_REQUEST_POST',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_TRANSACTION_REQUEST_AUTH_POST`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_TRANSACTION_REQUEST_AUTH_POST',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `FSPIOP_CALLBACK_URL_AUTHORIZATIONS`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'FSPIOP_CALLBACK_URL_AUTHORIZATIONS',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_ACCOUNTS_PUT`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_ACCOUNTS_PUT',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_ACCOUNTS_PUT_ERROR`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_ACCOUNTS_PUT_ERROR',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_CONSENT_REQUEST_PUT`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_CONSENT_REQUEST_PUT',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_CONSENT_REQUEST_PUT_ERROR`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_CONSENT_REQUEST_PUT_ERROR',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_CREATE_CREDENTIAL_POST`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_CREATE_CREDENTIAL_POST',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_CONSENT_POST`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_CONSENT_POST',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_CONSENT_GET`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_CONSENT_GET',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_CONSENT_PUT`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_CONSENT_PUT',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_CONSENT_PUT_ERROR`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_CONSENT_PUT_ERROR',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_SERVICES_PUT`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_SERVICES_PUT',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_SERVICES_PUT_ERROR`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_SERVICES_PUT_ERROR',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_CONSENT_PUT`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_CONSENT_PUT',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_CONSENT_PATCH`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_CONSENT_PATCH',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_ACCOUNTS_PUT_ERROR`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_ACCOUNTS_PUT_ERROR',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_TRANSACTION_REQUEST_POST`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_TRANSACTION_REQUEST_POST',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
        {
            name: 'register endpoint `TP_CB_URL_TRANSACTION_REQUEST_PUT_ERROR`',
            ignoreFailure: false,
            command: utils_1.wrapWithRunResult(() => requests_1.default.postEndpoint(globalConfig.urls.centralLedgerAdmin, {
                participantId: participant.id,
                body: {
                    type: 'TP_CB_URL_TRANSACTION_REQUEST_PUT_ERROR',
                    value: `${participant.thirdpartyCallbackUrl}`
                }
            }))
        },
    ];
};
function makeParticipantSteps(participant) {
    const constConfig = {
        id: `participant_${participant.id}`,
        name: `Participant Steps - ${participant.id}`,
        description: `Sets up participant steps for ${participant.id}`,
        ignoreFailure: false,
    };
    const stepGenerator = (config) => {
        let steps = makeCommonSteps(constConfig, config, participant);
        switch (participant.type) {
            case types_1.ParticipantType.DFSP: {
                return steps.concat(makeDfspSteps(constConfig, config, participant));
            }
            case types_1.ParticipantType.DFSP_SUPPORTING_PISP: {
                return steps.concat(makeDfspSteps(constConfig, config, participant), makeDFSPSupportingPISPSteps(constConfig, config, participant));
            }
            case types_1.ParticipantType.PISP: {
                return steps.concat(makePispSteps(constConfig, config, participant));
            }
        }
    };
    return (config) => new genericSteps_1.GenericSteps(constConfig, config, stepGenerator);
}
exports.default = makeParticipantSteps;
//# sourceMappingURL=participantSteps.js.map